pub struct DisplayReplayWindow {
pub scope: ReplayScope,
pub events: Vec<ReplayEvent>,
pub next_sequence: usize,
}Expand description
Display replay events and the next sequence for live tail continuation.
Fields
scope: ReplayScopeReplay scope used by the events.
events: Vec<ReplayEvent>Replay events after the requested cursor.
next_sequence: usizeNext sequence number for live events in this scope.