pub struct LocalStreamArchive { /* private fields */ }Expand description
Shared stream archive adapter backed by the CLI local SQLite store.
Implementations
Sourceimpl LocalStreamArchive
impl LocalStreamArchive
Sourcepub const fn new(config: CliConfig) -> Self
pub const fn new(config: CliConfig) -> Self
Create a local stream archive adapter from resolved CLI config.
Sourcepub fn replay_display_window(
&self,
session_id: &str,
run_id: Option<&str>,
cursor: Option<&ReplayCursor>,
) -> CliResult<DisplayReplayWindow>
pub fn replay_display_window( &self, session_id: &str, run_id: Option<&str>, cursor: Option<&ReplayCursor>, ) -> CliResult<DisplayReplayWindow>
Replay display messages as scoped replay events for local RPC and TUI hosts.