Cli

Struct Cli 

pub struct Cli {
Show 16 fields pub prompt: Option<String>, pub session: Option<String>, pub continue_session: bool, pub new_session: bool, pub run: Option<String>, pub branch_from: Option<String>, pub profile: Option<String>, pub worker: Option<String>, pub worker_label: Option<String>, pub worktree: Option<String>, pub worktree_name: Option<String>, pub branch: Option<String>, pub output: Option<OutputMode>, pub hitl: Option<HitlPolicy>, pub store: Option<String>, pub command: Option<CliCommand>,
}
Top-level CLI.

Fields

prompt: Option<String>

Prompt shorthand for headless runs.

session: Option<String>

Append a run to the selected session.

continue_session: bool

Continue the latest local session.

new_session: bool

Create a fresh session.

run: Option<String>

Restore from a specific run before appending a run.

branch_from: Option<String>

Branch from a specific run before appending a run.

profile: Option<String>

Agent profile name or YAML path.

worker: Option<String>

Enable worker mode or set an optional worker label.

worker_label: Option<String>

Explicit worker label.

worktree: Option<String>

Enable a git worktree or set an optional worktree name/path.

worktree_name: Option<String>

Explicit worktree name/path.

branch: Option<String>

Git branch for worktree metadata.

output: Option<OutputMode>

Output mode.

hitl: Option<HitlPolicy>

Headless human-in-the-loop policy for prompt shorthand.

store: Option<String>

Override local store database path.

command: Option<CliCommand>

Optional subcommand.